@@ -36,7 +36,8 @@ class Checktext(object):
             data = json.load(words_file)
         self.common_words = set(data)
         if wlist:
-            for new_words in wlist:
+            new_words = self.load_wlists(wlist)
+            if new_words:
                 new_dict = {word.strip() for word in new_words.splitlines()}
                 self.common_words.update(new_dict)
 
@@ -49,9 +50,20 @@ class Checktext(object):
         self.dale_chall_grade = {4.9: 'Grade 4 and below', 5.9: 'Grades 5-6', 6.9: 'Grades 7-8',
                 7.9: 'Grades 9-10', 8.9: 'Grades 11-12', 9.9: 'Grades 13-15'}
 
+    def load_wlists(self, wlist):
+        new_words = ''
+        try:
+            with open(wlist) as f:
+                new_words = f.read()
+        except:
+            for wl in wlist.split():
+                with open(wl) as f:
+                    new_words += f.read()
+        return new_words
+
     def run_check(self, data):
         """Check for uncommon words and difficult words in file."""
-        sentences = data.count(b'.') + data.count(b'!') + data.count(b'?')
+        sentences = data.count(b'.') + data.count(b'!') + data.count(b'?') or 1
         punc = b'!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~0123456789'
         data = data.translate(bytes.maketrans(punc, b' ' * len(punc)))
         words = Counter(data.decode('utf-8').lower().split())
